@@ -13,7 +13,7 @@ use constant DEBUG =>   # not used ...
 use Data::Dumper;
 $Data::Dumper::Indent = $Data::Dumper::Sortkeys = 1;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 #has [qw(auto_escape)];
 has [qw(code include_file)] => '';
@@ -62,11 +62,8 @@ sub interpret {
 
     $self->_set_get_post_request_params( $c, $params, $variables_order );
 
-    # XXX - should we always set $HTTP_RAW_POST_DATA?
-    my $input = $c->req->body;
-    if (my $len = length($input)) {
-	PHP::set_php_input( "$input" );
-	$params->{HTTP_RAW_POST_DATA} = "$input";
+    if (length($c->req->body)) {
+	$params->{HTTP_RAW_POST_DATA} = $c->req->body;
     }
 
     # hook to make adjustments to  %$params
@@ -89,6 +86,7 @@ sub interpret {
     }
     $c && $c->stash( 'php_params', $params );
 
+    _set_php_input($c, $params);
 
     my $OUTPUT;
     my $ERROR = "";
@@ -199,7 +197,8 @@ sub interpret {
 	if (!$c->res->code) {
 	    $c->res->code(302);
 	} elsif (500 == $c->res->code) {
-	    $log->info("changing response code from 500 to 302 because there's a location header");
+	    $log->info("changing response code from 500 to 302 "
+		       . "because there's a location header");
 	    $c->res->code(302);
 	    $log->info("output is\n\n" . $output);
 	    $log->info("active exception msg is: " . ($@ || ""));
@@ -211,6 +210,16 @@ sub interpret {
     return Mojo::Exception->new( $@, [$self->template, $self->code] );
 }
 
+sub _set_php_input {
+    my ($c, $params) = @_;
+    my $input = $c->req->body;
+    if (length($input)) {
+	PHP::set_php_input( "$input" );
+	$params->{HTTP_RAW_POST_DATA} = $input;
+    }
+    return;
+}
+
 sub _get_upload_metadata {
     my ($self, $upload) = @_;
 
@@ -276,9 +285,8 @@ sub _files_params {
 
 sub _cookie_params {
     my ($self, $c) = @_;
-    if (@{$c->req->cookies}) {
-	$DB::single = 'cookies!';
-    }
+
+    $DB::single = 1;
 
     # Mojo: $c->req->cookies is [], in Catalyst it is {}
     my $p = { 
@@ -324,9 +332,17 @@ sub _server_params {
 sub _mojoparams_to_phpparams {
     my ($query, @order) = @_;
     my $existing_params = {};
-    foreach my $name ($query->param) {
-	my @p = $query->param($name);
-	$existing_params->{$name} = @p > 1 ? [ @p ] : $p[0];
+    if ($Mojolicious::VERSION >= 6.00) {
+	my $p = $query->to_hash;
+	while (my ($k,$v) = each %$p) {
+	    $existing_params->{$k} = $v;
+	}
+    } else {
+	my @names = $query->param;
+	foreach my $name (@names) {
+	    my @p = $query->param($name);
+	    $existing_params->{$name} = @p > 1 ? [ @p ] : $p[0];
+	}
     }
 
     # XXX - what if parameter value is a Mojo::Upload ? Do we still
@@ -416,9 +432,10 @@ sub _set_get_post_request_params {
 		 $c->req->url->query, @order );
 	}
     }
-
     if ($var_order =~ /P/ && $c->req->method eq 'POST') {
-	my $order = [ $c->req->body_params->param ];
+	my $order = $Mojolicious::VERSION >= 6.00 
+		      ? $c->req->body_params->names
+		      : [ $c->req->body_params->param ];
 	$params->{_POST} = _mojoparams_to_phpparams(
 	    $c->req->body_params, @$order );
     }
@@ -488,7 +505,7 @@ MojoX::Template::PHP - PHP processing engine for MojoX::Plugin::PHP
 
 =head1 VERSION
 
-0.03
+0.04
 
 =head1 SYNOPSIS
 
@@ -615,7 +632,7 @@ Marty O'Brien E<lt>mob@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2013, Marty O'Brien. All rights reserved.
+Copyright 2013-2015, Marty O'Brien. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
